@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Mixed one vs. two spaces after a period.
 
 ---
@@ -23,5 +22,5 @@ def check(text):
     err = "consistency.spacing"
     msg = "Inconsistent spacing after period (1 vs. 2 spaces)."
 
-    regex = ["[\.\?!] [A-Z]", "[\.\?!]  [A-Z]"]
+    regex = [r"[\.\?!] [A-Z]", r"[\.\?!]  [A-Z]"]
     return consistency_check(text, [regex], err, msg)
