@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Inconsistent spelling.
 
 ---
@@ -33,6 +32,7 @@ def check(text):
         ["advisor", "adviser"],
         # ["analyse", "analyze"],
         ["centre", "center"],
+        ["colour", "color"],
         ["emphasise", "emphasize"],
         ["finalise", "finalize"],
         ["focussed", "focused"],
