@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Corporate speak.
 
 ---
@@ -17,10 +16,10 @@ from proselint.tools import existence_check, memoize
 
 
 @memoize
-def check_repeated_exclamations(text):
+def check(text):
     """Check the text."""
     err = "corporate_speak.misc"
-    msg = u"Minimize your use of corporate catchphrases like this one."
+    msg = "Minimize your use of corporate catchphrases like this one."
 
     list = [
         "at the end of the day",
