@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Words the NFL won't print on a jersey.
 
 ---
@@ -17,10 +16,10 @@ from proselint.tools import existence_check, memoize
 
 
 @memoize
-def check_debased_language(text):
+def check(text):
     """Check the text."""
     err = "cursing.nfl"
-    msg = u"The NFL won't print this word on a jersey."
+    msg = "The NFL won't print this word on a jersey."
 
     list = [
         "420",
