@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Chatspeak.
 
 ---
@@ -20,7 +19,7 @@ from proselint.tools import existence_check, memoize
 def check(text):
     """Check the text."""
     err = "misc.chatspeak"
-    msg = u"'{}' is chatspeak. Write it out."
+    msg = "'{}' is chatspeak. Write it out."
 
     words = [
         "2day",
