@@ -13,9 +13,10 @@ Strunk & White say:
 
 
 """
-from proselint.tools import memoize
 import re
 
+from proselint.tools import memoize
+
 
 @memoize
 def check(text):
@@ -39,7 +40,11 @@ def check(text):
     for word in bad_words:
         occ = [m for m in re.finditer(word, text.lower())]
         for o in occ:
-            errors.append((o.start(), o.end(), err,
-                          msg.format(word, explanations[word])))
+            errors.append((
+                o.start(),
+                o.end(),
+                err,
+                msg.format(word, explanations[word]),
+                None))
 
     return errors
