@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Pretension.
 
 ---
@@ -13,14 +12,15 @@ categories: writing
 Never use the phrase 'all hell broke loose'.
 
 """
-from proselint.tools import existence_check, memoize
+from proselint.tools import existence_check, max_errors, memoize
 
 
+@max_errors(1)
 @memoize
 def check(text):
     """Check the text."""
     err = "ogilvy.pretension"
-    msg = u"Jargon words like this one are the hallmarks of a pretentious ass."
+    msg = "Jargon words like this one are the hallmarks of a pretentious ass."
 
     list = [
         "reconceptualize",
@@ -29,4 +29,4 @@ def check(text):
         "judgmentally",
     ]
 
-    return existence_check(text, list, err, msg, max_errors=1)
+    return existence_check(text, list, err, msg)
