@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Tense present.
 
 ---
@@ -13,18 +12,19 @@ categories: writing
 Archaism.
 
 """
-from proselint.tools import memoize
 import re
 
+from proselint.tools import memoize
+
 
 @memoize
 def check(text):
     """Check the text."""
     err = "misc.tense_present"
-    msg = u"'{}'."
+    msg = r"'{}'."
 
     illogics = [
-        u"up to \d{1,3}% ?[-\u2014\u2013]{0,3} ?(?:or|and) more\W?",
+        r"up to \d{1,3}% ?[-\u2014\u2013]{0,3} ?(?:or|and) more\W?",
         "between you and I",
         "on accident",
         "somewhat of a",
@@ -34,13 +34,18 @@ def check(text):
         "in regards to",
         "would of",
         # "and so",
-        "i ?(?:feel|am feeling|am|'m|'m feeling) nauseous",
+        r"i ?(?:feel|am feeling|am|'m|'m feeling) nauseous",
     ]
 
     errors = []
     for i in illogics:
-        for m in re.finditer(u"\s{}\s".format(i), text, flags=re.U | re.I):
+        for m in re.finditer(fr"\s{i}\s", text, flags=re.U | re.I):
             txt = m.group(0).strip()
-            errors.append((m.start() + 1, m.end(), err, msg.format(txt)))
+            errors.append((
+                m.start() + 1,
+                m.end(),
+                err,
+                msg.format(txt),
+                None))
 
     return errors
