@@ -1,10 +1,10 @@
-# -*- coding: utf-8 -*-
-
 """Mixed metaphors."""
 
-from proselint.tools import memoize, existence_check, preferred_forms_check
+from proselint.tools import (existence_check, max_errors, memoize,
+                             preferred_forms_check)
 
 
+@max_errors(1)
 @memoize
 def check_bottleneck(text):
     """Avoid mixing metaphors about bottles and their necks.
@@ -13,7 +13,7 @@ def check_bottleneck(text):
     source_url: http://bit.ly/1CQPH61
     """
     err = "mixed_metaphors.misc.bottleneck"
-    msg = u"Mixed metaphor — bottles with big necks are easy to pass through."
+    msg = "Mixed metaphor — bottles with big necks are easy to pass through."
     list = [
         "biggest bottleneck",
         "big bottleneck",
@@ -24,7 +24,7 @@ def check_bottleneck(text):
         "massive bottleneck",
     ]
 
-    return existence_check(text, list, err, msg, max_errors=1)
+    return existence_check(text, list, err, msg)
 
 
 @memoize
@@ -35,7 +35,7 @@ def check_misc(text):
     source_url: http://bit.ly/1T4alrY
     """
     err = "mixed_metaphors.misc.misc"
-    msg = u"Mixed metaphor. Try '{}'."
+    msg = "Mixed metaphor. Try '{}'."
 
     preferences = [
 
