@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Mondegreens.
 
 ---
@@ -25,7 +24,7 @@ def check(text):
     list = [
         ["a girl with kaleidoscope eyes", ["a girl with colitis goes by"]],
         ["a partridge in a pear tree",    ["a part-red gingerbread tree"]],
-        ["attorney and not a republic",   ["attorney and notary public"]],
+        ["attorney and notary public",    ["attorney and not a republic"]],
         ["beck and call",                 ["beckon call"]],
         ["for all intents and purposes",  ["for all intensive purposes"]],
         ["laid him on the green",         ["Lady Mondegreen"]],
