@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Oxymorons.
 
 ---
@@ -20,7 +19,7 @@ from proselint.tools import existence_check, memoize
 def check(text):
     """Check the text."""
     err = "oxymorons.misc"
-    msg = u"'{}' is an oxymoron."
+    msg = "'{}' is an oxymoron."
 
     oxymorons = [
         "amateur expert",
@@ -36,7 +35,6 @@ def check(text):
         "build down",
         "conspicuous absence",
         "exact estimate",
-        "executive secretary",
         "found missing",
         "intense apathy",
         "mandatory choice",
@@ -44,6 +42,7 @@ def check(text):
         "organized mess",
         # "pretty ugly",
         # "sure bet",
+        # "executive secretary",
     ]
 
     return existence_check(text, oxymorons, err, msg, offset=1, join=True)
