@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Skunked terms.
 
 ---
@@ -17,10 +16,10 @@ from proselint.tools import existence_check, memoize
 
 
 @memoize
-def check_skunked(text):
+def check(text):
     """Check the text."""
     err = "skunked_terms.misc"
-    msg = u"""'{}' is a bit of a skunked term — impossible to use without issue.
+    msg = """'{}' is a bit of a skunked term, impossible to use without issue.
              Find some other way to say it."""
 
     skunked_terms = [
