@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Very.
 
 ---
@@ -10,20 +9,21 @@ date:       2014-06-10 12:31:19
 categories: writing
 ---
 
-Substitute 'damn' every time you're inclined to write 'very;' your editor will
+Substitute 'damn' every time you're inclined to write 'very'; your editor will
 delete it and the writing will be just as it should be.
 
 """
-from proselint.tools import memoize, existence_check
+from proselint.tools import existence_check, max_errors, memoize
 
 
+@max_errors(1)
 @memoize
 def check(text):
     """Avoid 'very'."""
     err = "weasel_words.very"
     msg = ("Substitute 'damn' every time you're "
-           "inclined to write 'very;' your editor will delete it "
+           "inclined to write 'very'; your editor will delete it "
            "and the writing will be just as it should be.")
     regex = "very"
 
-    return existence_check(text, [regex], err, msg, max_errors=1)
+    return existence_check(text, [regex], err, msg)
