@@ -1,32 +1,26 @@
-# -*- coding: utf-8 -*-
-
 """Command line utility for proselint."""
-from __future__ import print_function
-from __future__ import absolute_import
-from builtins import str
 
-
-import click
+import json
 import os
-from .tools import (
-    close_cache_shelves_after,
-    close_cache_shelves,
-    errors_to_json,
-    lint,
-)
 import shutil
 import subprocess
 import sys
-from .version import __version__
 import traceback
 
+import click
 
-CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
+from .config import default
+from .tools import (close_cache_shelves, close_cache_shelves_after,
+                    errors_to_json, lint, load_options)
+from .version import __version__
+
+CONTEXT_SETTINGS = {"help_option_names": ['-h', '--help']}
 base_url = "proselint.com/"
 proselint_path = os.path.dirname(os.path.realpath(__file__))
 demo_file = os.path.join(proselint_path, "demo.md")
 
 
+# TODO: fix broken corpus
 def timing_test(corpus="0.1.0"):
     """Measure timing performance on the named corpus."""
     import time
@@ -94,6 +88,8 @@ def print_errors(filename, errors, output_json=False, compact=False):
 
 @click.command(context_settings=CONTEXT_SETTINGS)
 @click.version_option(__version__, '--version', '-v', message='%(version)s')
+@click.option('--config', is_flag=False, type=click.Path(),
+              help="Path to configuration file.")
 @click.option('--debug', '-d', is_flag=True, help="Give verbose output.")
 @click.option('--clean', '-c', is_flag=True, help="Clear the cache.")
 @click.option('--json', '-j', 'output_json', is_flag=True,
@@ -101,13 +97,26 @@ def print_errors(filename, errors, output_json=False, compact=False):
 @click.option('--time', '-t', is_flag=True, help="Time on a corpus.")
 @click.option('--demo', is_flag=True, help="Run over demo file.")
 @click.option('--compact', is_flag=True, help="Shorten output.")
+@click.option('--dump-config', is_flag=True, help="Prints current config.")
+@click.option('--dump-default-config', is_flag=True,
+              help="Prints default config.")
 @click.argument('paths', nargs=-1, type=click.Path())
 @close_cache_shelves_after
-def proselint(paths=None, version=None, clean=None, debug=None,
-              output_json=None, time=None, demo=None, compact=None):
-    """A CLI for proselint, a linter for prose."""
+def proselint(paths=None, config=None, version=None, clean=None,
+              debug=None, output_json=None, time=None, demo=None, compact=None,
+              dump_config=None, dump_default_config=None):
+    """Create the CLI for proselint, a linter for prose."""
+    if dump_default_config:
+        return print(json.dumps(default, sort_keys=True, indent=4))
+
+    config = load_options(config, default)
+    if dump_config:
+        print(json.dumps(config, sort_keys=True, indent=4))
+        return
+
     if time:
-        click.echo(timing_test())
+        # click.echo(timing_test())
+        print("This option does not work for the time being.")
         return
 
     # In debug or clean mode, delete cache & *.pyc files before running.
@@ -129,18 +138,18 @@ def proselint(paths=None, version=None, clean=None, debug=None,
         filepaths.append('-')
 
     for fp in filepaths:
-        try:
-            if fp == '-':
-                fp = '<stdin>'
-                f = sys.stdin
-            else:
-                f = click.open_file(
-                    fp, 'r', encoding="utf-8", errors="replace")
-            errors = lint(f, debug=debug)
-            num_errors += len(errors)
-            print_errors(fp, errors, output_json, compact=compact)
-        except Exception:
-            traceback.print_exc()
+        if fp == '-':
+            fp = '<stdin>'
+            f = sys.stdin
+        else:
+            try:
+                f = click.open_file(fp, 'r', "utf-8", "replace")
+            except Exception:
+                traceback.print_exc()
+                sys.exit(2)
+        errors = lint(f, debug, config)
+        num_errors += len(errors)
+        print_errors(fp, errors, output_json, compact)
 
     # Return an exit code
     close_cache_shelves()
