@@ -1,10 +1,10 @@
 """Test version number."""
-from __future__ import absolute_import
-from __future__ import print_function
+from click.testing import CliRunner
+
+from proselint.command_line import proselint
+from proselint.version import __version__
 
 from .check import Check
-from proselint.version import __version__
-import subprocess
 
 
 class TestCheck(Check):
@@ -14,5 +14,7 @@ class TestCheck(Check):
 
     def test_version(self):
         """Make sure the version number is correct."""
-        out = subprocess.check_output(["proselint", "--version"])
-        assert out.decode('utf-8') == __version__ + "\n"
+        runner = CliRunner()
+
+        output = runner.invoke(proselint, "--version")
+        assert __version__ in output.stdout
