@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Tests for the clear cache operation from proselint.command_line."""
 
 import os
@@ -6,12 +5,11 @@ import unittest
 
 from proselint import command_line as cl
 
-
 try:
     from unittest import mock
 except ImportError:
     # Py2.x
-    import mock
+    from unittest import mock
 
 try:
     from builtins import PermissionError
