@@ -1,9 +1,8 @@
 """Test garner.dates."""
-from __future__ import absolute_import
-from __future__ import print_function
+
+from proselint.checks.dates_times import dates
 
 from .check import Check
-from proselint.checks.dates_times import dates
 
 
 class TestCheck(Check):
