@@ -1,10 +1,9 @@
 """Tests for misc.bureaucratese check."""
-from __future__ import absolute_import
-
-from .check import Check
 
 from proselint.checks.misc import bureaucratese as chk
 
+from .check import Check
+
 
 class TestCheck(Check):
     """The test class for misc.bureaucratese."""
@@ -13,7 +12,7 @@ class TestCheck(Check):
 
     @property
     def this_check(self):
-        """Bolierplate."""
+        """Boilerplate."""
         return chk
 
     def test_smoke(self):
