@@ -1,10 +1,14 @@
 """Test the tools module."""
 
-from __future__ import absolute_import
+
+from proselint.config import default
+from proselint.tools import lint as proselint, load_options
 
 from .check import Check
 
-from proselint.tools import lint as lint
+
+def lint(text):
+    return proselint(text, config=load_options(conf_default=default))
 
 
 class TestLint(Check):
