@@ -1,18 +1,13 @@
 """Tests for weasel_words.misc check."""
-from __future__ import absolute_import
-
-from .check import Check
 
 from proselint.checks.weasel_words import misc as chk
-from nose import SkipTest
+
+from .check import Check
 
 
 class TestCheck(Check):
     """The test class for weasel_words.misc."""
-
-    raise SkipTest
-
-    __test__ = True
+    __test__ = False
 
     @property
     def this_check(self):
@@ -22,4 +17,4 @@ class TestCheck(Check):
     def test_smoke(self):
         """Basic smoke test for weasel_words.misc."""
         assert self.passes("""Smoke phrase with nothing flagged.""")
-        # FIXME add test when check is implemented
+        # TODO: add test when check is implemented
